recsyslearn.fairness package
============================

Submodules
----------

recsyslearn.fairness.metrics module
-----------------------------------

.. automodule:: recsyslearn.fairness.metrics
   :members:
   :undoc-members:
   :show-inheritance:

recsyslearn.fairness.utils module
---------------------------------

.. automodule:: recsyslearn.fairness.utils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: recsyslearn.fairness
   :members:
   :undoc-members:
   :show-inheritance:
